import os

from bluer_options.env import load_config, load_env, get_env
from bluer_objects.env import abcli_path_git

load_config(__name__)


BLUER_ALGO_FRUITS_360_REPO_ADDRESS = get_env("BLUER_ALGO_FRUITS_360_REPO_ADDRESS")
BLUER_ALGO_FRUITS_360_REPO_PATH = os.path.join(abcli_path_git, "fruits-360-100x100")

BLUER_ALGO_FRUITS_360_TEST_DATASET = get_env("BLUER_ALGO_FRUITS_360_TEST_DATASET")
BLUER_ALGO_SWALLOW_TEST_DATASET = get_env("BLUER_ALGO_SWALLOW_TEST_DATASET")

BLUER_ALGO_FRUITS_360_TEST_MODEL = get_env("BLUER_ALGO_FRUITS_360_TEST_MODEL")

BLUER_ALGO_FRUITS_360_TEST_MODEL_2000 = get_env("BLUER_ALGO_FRUITS_360_TEST_MODEL_2000")

BLUER_ALGO_TRACKER_LOG_PERIOD = get_env(
    "BLUER_ALGO_TRACKER_LOG_PERIOD",
    1,
)
BLUER_ALGO_TRACKER_LOG_FRAME = get_env(
    "BLUER_ALGO_TRACKER_LOG_FRAME",
    5,
)

BLUER_ALGO_COCO128_TEST_DATASET = get_env("BLUER_ALGO_COCO128_TEST_DATASET")
BLUER_ALGO_COCO128_TEST_MODEL = get_env("BLUER_ALGO_COCO128_TEST_MODEL")

BLUER_AI_BPS_LOOP_BEACON_LENGTH_MIN = get_env(
    "BLUER_AI_BPS_LOOP_BEACON_LENGTH_MIN",
    20,
)
BLUER_AI_BPS_LOOP_BEACON_LENGTH_MAX = get_env(
    "BLUER_AI_BPS_LOOP_BEACON_LENGTH_MAX",
    40,
)
BLUER_AI_BPS_LOOP_RECEIVER_LENGTH_MIN = get_env(
    "BLUER_AI_BPS_LOOP_RECEIVER_LENGTH_MIN",
    20,
)
BLUER_AI_BPS_LOOP_RECEIVER_LENGTH_MAX = get_env(
    "BLUER_AI_BPS_LOOP_RECEIVER_LENGTH_MAX",
    40,
)
BLUER_AI_BPS_LOOP_GREP = get_env("BLUER_AI_BPS_LOOP_GREP")

BLUER_ALGO_BPS_REVIEW_TEST_OBJECT = get_env("BLUER_ALGO_BPS_REVIEW_TEST_OBJECT")
